"""Test classmethods."""
from pathlib import Path

from treestamps import Treestamps


__all__ = ()


class TestClassMethodds:
    def test_get_filename(self):
        assert Treestamps._get_filename("foo") == ".foo_treestamps.yaml"

    def test_get_wal_filename(self):
        assert Treestamps._get_wal_filename("foo") == ".foo_treestamps.wal.yaml"

    def test_normalize_config(self):
        assert Treestamps._normalize_config(None) is None
        assert Treestamps._normalize_config({}) == {}
        assert Treestamps._normalize_config({"a": 1}) == {"a": 1}
        assert Treestamps._normalize_config({"a": 1, "b": [3, 2, 1, 2]}) == {
            "a": 1,
            "b": [1, 2, 3],
        }
        assert Treestamps._normalize_config({"a": {"b": [2, 1, 3, 1]}}) == {
            "a": {"b": [1, 2, 3]}
        }

    def test_factory(self):
        path_a = Path(__file__).resolve()
        path_b = path_a.parent
        path_c = Path("/tmp")

        paths = (path_a, path_b, path_c)

        program_name = "foo"

        map = Treestamps.path_to_treestamps_map_factory(paths, program_name)

        dirset = set([path_b, path_c])
        assert set(map.keys()) == dirset
        dirs = set([ts.dir for ts in map.values()])
        assert dirs == dirset



"""Test static methods."""
from pathlib import Path

from treestamps import Treestamps


__all__ = ()


class TestStaticMethods:
    def test_dirpath(self):
        file_path = Path(__file__).resolve()
        dir_path = file_path.parent
        assert Treestamps.dirpath(dir_path) == dir_path
        assert Treestamps.dirpath(file_path) == dir_path

    def test_maxnone(self):
        assert Treestamps.max_none(1, 2) == 2
        assert Treestamps.max_none(None, 2) == 2
        assert Treestamps.max_none(1, None) == 1
        assert Treestamps.max_none(None, None) is None

    def test_prune_dict(self):
        assert Treestamps.prune_dict(None, ["a"]) is None
        assert Treestamps.prune_dict({"a": 1, "b": 2}, None) == {"a": 1, "b": 2}
        assert Treestamps.prune_dict({"a": 1, "b": 2}, ["a"]) == {"a": 1}



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tests', 'tests.unit']

package_data = \
{'': ['*']}

modules = \
['treestamps']
install_requires = \
['ruamel.yaml>=0.17.21,<0.18.0', 'termcolor>=1.1.0,<2.0.0']

setup_kwargs = {
    'name': 'treestamps',
    'version': '0.2.0',
    'description': 'Create timestamp records for recursive operations on directory trees.',
    'long_description': '# Treestamps\n\nA library to set and retrieve timestamps to speed up operations\nrun recursively on directory trees.\n\nPrincipal methods on the Treestamps class are: init(), get(), set(), dump().\nA factory method is also provided for creating top path to Treestamp maps.\n\nDocumentation is to read the code for now.\n',
    'author': 'AJ Slater',
    'author_email': 'aj@slater.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ajslater/treestamps',
    'packages': packages,
    'package_data': package_data,
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
